# leppard

Yes, this exists solely as an excuse for me to write the line `def leppard():` and have it run.

Almost disappointed that nobody's made this joke already...

## Installing

```
pip install leppard
```

## Using

Run `import leppard` in your REPL of choice and watch the :sparkles: magic :sparkles: happen...

### (Actually using this)

I think this is a decent python package name and I don't think it should just be a joke/placeholder package forever.

I've been sitting on the name for a while and haven't come up with a decent use for it yet. If you have a good one, let me know and I'll happily hand over the reins!
